==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGroupingDoneEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebGroupingDoneEventArgsDetailDescription } from "./WebGroupingDoneEventArgsDetailDescription";
/**
 * @hidden
 */
var WebGroupingDoneEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupingDoneEventArgsDetailDescriptionMetadata, _super);
    function WebGroupingDoneEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingDoneEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebGroupingDoneEventArgsDetailDescriptionMetadata.a == null) {
            WebGroupingDoneEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingDoneEventArgsDetailDescriptionMetadata.c(WebGroupingDoneEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebGroupingDoneEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupingDoneEventArgsDetailDescriptionMetadata.a);
        WebSortingExpressionDescriptionMetadata.d(a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebGroupingDoneEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GroupingDoneEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Expressions", "Array:WebSortingExpressionDescription:SortingExpression");
        a.item("GroupedColumns", "Array:WebColumnDescription:Column");
        a.item("UngroupedColumns", "Array:WebColumnDescription:Column");
    };
    WebGroupingDoneEventArgsDetailDescriptionMetadata.d = function (a) {
        WebGroupingDoneEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebGroupingDoneEventArgsDetail", function () { return new WebGroupingDoneEventArgsDetailDescription(); });
        a.z("WebGroupingDoneEventArgsDetail", WebGroupingDoneEventArgsDetailDescriptionMetadata.a);
    };
    WebGroupingDoneEventArgsDetailDescriptionMetadata.$t = markType(WebGroupingDoneEventArgsDetailDescriptionMetadata, 'WebGroupingDoneEventArgsDetailDescriptionMetadata');
    WebGroupingDoneEventArgsDetailDescriptionMetadata.a = null;
    return WebGroupingDoneEventArgsDetailDescriptionMetadata;
}(Base));
export { WebGroupingDoneEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGroupingDoneEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebGroupingDoneEventArgsDetailDescription } from "./WebGroupingDoneEventArgsDetailDescription";
/**
 * @hidden
 */
var WebGroupingDoneEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupingDoneEventArgsDetailDescriptionMetadata, _super);
    function WebGroupingDoneEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingDoneEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebGroupingDoneEventArgsDetailDescriptionMetadata.a == null) {
            WebGroupingDoneEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingDoneEventArgsDetailDescriptionMetadata.c(WebGroupingDoneEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebGroupingDoneEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupingDoneEventArgsDetailDescriptionMetadata.a);
        WebSortingExpressionDescriptionMetadata.d(a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebGroupingDoneEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GroupingDoneEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Expressions", "Array:WebSortingExpressionDescription:SortingExpression");
        a.item("GroupedColumns", "Array:WebColumnDescription:Column");
        a.item("UngroupedColumns", "Array:WebColumnDescription:Column");
    };
    WebGroupingDoneEventArgsDetailDescriptionMetadata.d = function (a) {
        WebGroupingDoneEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebGroupingDoneEventArgsDetail", function () { return new WebGroupingDoneEventArgsDetailDescription(); });
        a.ab("WebGroupingDoneEventArgsDetail", WebGroupingDoneEventArgsDetailDescriptionMetadata.a);
    };
    WebGroupingDoneEventArgsDetailDescriptionMetadata.$t = markType(WebGroupingDoneEventArgsDetailDescriptionMetadata, 'WebGroupingDoneEventArgsDetailDescriptionMetadata');
    WebGroupingDoneEventArgsDetailDescriptionMetadata.a = null;
    return WebGroupingDoneEventArgsDetailDescriptionMetadata;
}(Base));
export { WebGroupingDoneEventArgsDetailDescriptionMetadata };
